@@ -39,7 +39,7 @@ use warnings::unused;
 
 our @EXPORT = qw( retrieve report get_files );
 
-$VERSION = '0.53'; # our $VERSION = '';
+$VERSION = '0.53.1'; # our $VERSION = '';
 $ABSTRACT = 'Sim::OPT::Report is the module used by Sim::OPT to retrieve simulation results.';
 
 #########################################################################################
@@ -1069,7 +1069,13 @@ sub report # This function retrieves the results of interest from the texts file
               {
                 $semaphore2 = "off"; 
               }
-            
+              
+              $line =~ s/  / / ;
+		  	  $line =~ s/  / / ;
+		  	  $line =~ s/  / / ;
+		  	  $line =~ s/  / / ;
+		  	  $line =~ s/  / / ;
+  			  $line =~ s/ /,/ ;
               chomp( $line ); chomp( $line ); 
               #$line = $line . " ";
               
@@ -1204,7 +1210,6 @@ sub report # This function retrieves the results of interest from the texts file
   #{
     print REPFILE "$_\n"; 
   #}
-  
   close REPFILE;
     
   say $tee "HEREIS \@repcases " . dump(@repcases); say $tee "\@repstruct " . dump(@repstruct); 
